@@ -1,13 +1,14 @@
 from .blacklist import BlacklistToken
+from .session import Session
 from ..api import database as db, flask_bcrypt, config
 
 
 class Auth(db.Model):
     __tablename__ = "auth"
 
-    id = db.Column(db.Integer, primary_key=True, autoincrement=True)
+    aid = db.Column(db.Integer, primary_key=True, autoincrement=True)
     email = db.Column(db.String(255), unique=True, nullable=False)
-    passsword_hash = db.Column(db.String(255), nullable=True )
+    password_hash = db.Column(db.String(255), nullable=True )
 
     user_type = db.Column(db.String(255), nullable=True)
 
@@ -25,10 +26,35 @@ class Auth(db.Model):
     @staticmethod
     def login(email, password, user_type=None):
         try:
-            user = Auth.query.filter_by(email=data.get('email')).first()
-            if user and user.check_password(data.get('password')):
-                return True
+            auth = Auth.query.filter_by(email=email).first()
+            if auth and auth.check_password(password):
+                if not user_type or (user_type and auth.user_type == user_type):
+                    session = Session.open()
+                    session.save()
+                    return session
+                return False
             else:
                 return False
         except Exception as e:
             return None
+    
+    @staticmethod
+    def get_session():
+        auth_header = request.headers.get('Authorization')
+        if auth_header:
+            try:
+                auth_token = auth_header.split(" ")[1]
+            except IndexError:
+                return None
+        else:
+            auth_token = None
+
+        if auth_token:
+            session = Session.open(auth_token)
+            
+            if session:
+                return session
+            return None
+        else:
+            return None
+
