@@ -5,6 +5,8 @@ import datetime
 import jwt
 from itsdangerous import want_bytes
 
+import os
+key = os.getenv("SECRET_KEY")
 
 class Session(db.Model):
     __tablename__ = "session"
@@ -32,10 +34,10 @@ class Session(db.Model):
             new_session = Session(session_id=sid, expiry=datetime.datetime.utcnow() + datetime.timedelta(days=1, seconds=5))
             val = pickle.dumps(dict())
             new_session.data = val
-            db.session.add(new_session)
-            db.session.commit()
             auth_token = Session.encode_auth_token(sid=sid)
             new_session.data_["auth_token"] = auth_token
+            db.session.add(new_session)
+            db.session.commit()
             return new_session
         else:
             sid = Session.decode_auth_token(auth_token)
@@ -67,25 +69,22 @@ class Session(db.Model):
         db.session.add(self)
         db.session.commit()
 
-
     @staticmethod 
     def encode_auth_token(sid):
         try:
             payload = {'sid': sid}
-            token = jwt.encode(
+            return jwt.encode(
                 payload,
-                config["key"],
+                key,
                 algorithm='HS256'
-            ).decode('utf-8')
-            return token
+            ).decode()
         except Exception as e:
             return e
         
     @staticmethod  
     def decode_auth_token(auth_token):
         try:
-            payload = jwt.decode(auth_token, config["key"], algorithms=['HS256'])
+            payload = jwt.decode(auth_token, key)
             return payload["sid"]
-        except Exception as e:
+        except:
             return False
-
